Andreas Krennmair:
authorak1 <ak1@e385b8ad-14ed-0310-8656-cc95a2468c6d>
Thu, 24 Feb 2005 16:36:18 +0000 (16:36 +0000)
committerak1 <ak1@e385b8ad-14ed-0310-8656-cc95a2468c6d>
Thu, 24 Feb 2005 16:36:18 +0000 (16:36 +0000)
corrected misunderstanding, _fl_agged, not _t_agged.

git-svn-id: svn://svn.berlios.de/mutt-ng/trunk@88 e385b8ad-14ed-0310-8656-cc95a2468c6d

ChangeLog.mutt-ng
buffy.c
buffy.h
sidebar.c

index 0dac4d6..4ef59a5 100644 (file)
@@ -2,7 +2,7 @@ Changes specific to mutt-ng:
 
 2005-02-24:
   * Integrated another sidebar fix and a build fix from Rocco Rutte.
-  * Implemented feature request that the number of tagged messages is shown in the sidebar
+  * Implemented feature request that the number of flagged messages is shown in the sidebar
 
 2005-02-23:
   * Integrated assume_charset patch from http://www.emaillab.org/mutt/download15.html.en
diff --git a/buffy.c b/buffy.c
index 757d583..6b91745 100644 (file)
--- a/buffy.c
+++ b/buffy.c
@@ -404,7 +404,7 @@ int mutt_buffy_check (int force)
        }
        tmp->msgcount = 0;
        tmp->msg_unread = 0;
-       tmp->msg_tagged = 0;
+       tmp->msg_flagged = 0;
        while ((de = readdir (dirp)) != NULL)
        {
          char *p;
--- a/sidebar.c
+++ b/sidebar.c
@@ -133,7 +133,7 @@ static char * shortened_hierarchy(char * box) {
   return safe_strdup(box);
 }
 
-char *make_sidebar_entry(char *box, int size, int new, int tagged)
+char *make_sidebar_entry(char *box, int size, int new, int flagged)
 {
   char *c;
   int i = 0, dlen = mutt_strlen (SidebarDelim);
@@ -156,16 +156,16 @@ char *make_sidebar_entry(char *box, int size, int new, int tagged)
   strncpy( entry, box, i < SidebarWidth - dlen ? i :SidebarWidth - dlen);
 
   if ( new ) {
-    if (tagged>0) {
-      sprintf(entry + SidebarWidth - 5 - quick_log10(size) - dlen - quick_log10(new) - quick_log10(tagged),
-              "% d(%d)[%d]", size, new, tagged);
+    if (flagged>0) {
+      sprintf(entry + SidebarWidth - 5 - quick_log10(size) - dlen - quick_log10(new) - quick_log10(flagged),
+              "% d(%d)[%d]", size, new, flagged);
     } else {
       sprintf(entry + SidebarWidth - 3 - quick_log10(size) - dlen - quick_log10(new),
               "% d(%d)", size, new);
     }
   } else {
-    if (tagged>0) {
-      sprintf( entry + SidebarWidth - 3 - quick_log10(size) - dlen - quick_log10(tagged), "% d[%d]", size,tagged);
+    if (flagged>0) {
+      sprintf( entry + SidebarWidth - 3 - quick_log10(size) - dlen - quick_log10(flagged), "% d[%d]", size,flagged);
     } else {
       sprintf( entry + SidebarWidth - 1 - quick_log10(size) - dlen, "% d", size);
     }
@@ -206,7 +206,7 @@ void set_buffystats (CONTEXT* Context)
     {
       tmp->msg_unread = Context->unread;
       tmp->msgcount = Context->msgcount;
-      tmp->msg_tagged = Context->flagged;
+      tmp->msg_flagged = Context->flagged;
       break;
     }
     tmp = tmp->next;
@@ -273,15 +273,15 @@ int draw_sidebar(int menu) {
     if ( Context && !strcmp( tmp->path, Context->path ) ) {
       printw( "%.*s", SidebarWidth - delim_len,
               make_sidebar_entry(basename(tmp->path),
-                                 Context->msgcount, Context->unread, Context->tagged));
+                                 Context->msgcount, Context->unread, Context->flagged));
       tmp->msg_unread = Context->unread;
       tmp->msgcount = Context->msgcount;
-      tmp->msg_tagged = Context->tagged;
+      tmp->msg_flagged = Context->flagged;
     }
     else
       printw( "%.*s", SidebarWidth - delim_len,
               make_sidebar_entry(basename(tmp->path),
-                                 tmp->msgcount,tmp->msg_unread, tmp->msg_tagged));
+                                 tmp->msgcount,tmp->msg_unread, tmp->msg_flagged));
     lines++;
   }
   SETCOLOR(MT_COLOR_NORMAL);
diff --git a/buffy.h b/buffy.h
index 8b0ec1b..94a325c 100644 (file)
--- a/buffy.h
+++ b/buffy.h
@@ -32,7 +32,7 @@ typedef struct buffy_t
   short has_new;               /* set it new if new and not read */
   int msgcount;                        /* total number of messages */
   int msg_unread;              /* number of unread messages */
-  int msg_tagged;              /* number of tagged messages */
+  int msg_flagged;             /* number of flagged messages */
   short notified;              /* user has been notified */
   short magic;                 /* mailbox type */
   short newly_created;         /* mbox or mmdf just popped into existence */
index 4f5d17c..8699196 100644 (file)